function p=ldltm(A,s)
%
%   p=ldltm(A,s)
%
%   Esta función calcula el numero p de valores propios mayores
%   que s que posee la matriz tridiagonal y simétrica A
%
%   Variables de Entrada:
%
% A   Matriz tridiagonal y simétrica
% s   Número real
%
%   Variables de Salida:
%
% p   Número de valores propios mayores que s
%
em=eps/2;
e=em^10;
n=size(A,1);
d=A(1,1)-s;
if d == 0
   d=e;
end
if d > 0
   p=1;
else
   p=0;
end
for i=2:n
   d=A(i,i)-s-A(i,i-1)^2/d;
   if d == 0
      d=e;
      p=p+1;
   elseif d > 0
      p=p+1;
   end
end